@@ -28,4 +28,10 @@ sub update{
     }
     $self;
 }
+
+sub send {
+    my $self = shift;
+    my $content = shift;
+    $self->{_client}->send_sess_message($self,$content);
+} 
 1;
