@@ -89,4 +89,10 @@ sub update{
     }
     $self;
 }
+
+sub send {
+    my $self = shift;
+    my $content = shift;
+    $self->{_client}->send_group_message($self,$content);
+} 
 1;
